This is an automated email from the ASF dual-hosted git repository.

diqiu50 pushed a commit to branch feature/10448-non-interactive-release
in repository https://gitbox.apache.org/repos/asf/gravitino.git

commit 85ac772e64249dc81ebafa827d83caece0b61604
Author: diqiu50 <[email protected]>
AuthorDate: Wed Mar 18 14:39:56 2026 +0800

    fix: use finalize as example step in help output
---
 dev/release/do-release.sh | 4 ++--
 1 file changed, 2 insertions(+), 2 deletions(-)

diff --git a/dev/release/do-release.sh b/dev/release/do-release.sh
index cceb51a1c1..d2fe707ccf 100755
--- a/dev/release/do-release.sh
+++ b/dev/release/do-release.sh
@@ -57,8 +57,8 @@ while getopts ":b:s:p:t:r:nyh" opt; do
       echo "  export ASF_USERNAME='myuser'"
       echo "  $0 -b branch-1.2 -r 1 -y"
       echo ""
-      echo "  # Run a single step only (e.g., build):"
-      echo "  $0 -b branch-1.2 -r 1 -s build -y"
+      echo "  # Run a single step only (e.g., finalize):"
+      echo "  $0 -b branch-1.2 -r 1 -s finalize -y"
       echo ""
       echo "  # Dry run to test without publishing:"
       echo "  $0 -n -b branch-1.2"

Reply via email to